pub struct HighlightPlugin { /* private fields */ }Expand description
Plugin that adds syntax highlighting CSS classes to code blocks.
Runs in after_compile. Finds <pre><code class="language-X">
blocks and injects classes. Also generates highlight.css.
Implementations
Sourceimpl HighlightPlugin
impl HighlightPlugin
Sourcepub fn new(theme: impl Into<String>) -> Self
pub fn new(theme: impl Into<String>) -> Self
Creates a new HighlightPlugin with the given theme.
Examples
use ssg::highlight::HighlightPlugin;
use ssg::plugin::Plugin;
let p = HighlightPlugin::new("monokai");
assert_eq!(p.name(), "highlight");Sourcepub fn with_theme(theme: impl Into<String>) -> Self
pub fn with_theme(theme: impl Into<String>) -> Self
Creates a highlight plugin with the given theme name.
Examples
use ssg::highlight::HighlightPlugin;
use ssg::plugin::Plugin;
let p = HighlightPlugin::with_theme("solarized");
assert_eq!(p.name(), "highlight");Trait Implementations
Sourceimpl Clone for HighlightPlugin
impl Clone for HighlightPlugin
Sourcefn clone(&self) -> HighlightPlugin
fn clone(&self) -> HighlightPlugin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HighlightPlugin
impl Debug for HighlightPlugin
Sourceimpl Default for HighlightPlugin
impl Default for HighlightPlugin
Sourceimpl Plugin for HighlightPlugin
impl Plugin for HighlightPlugin
Sourcefn has_transform(&self) -> bool
fn has_transform(&self) -> bool
Returns
true if this plugin implements transform_html.
Override to true to opt in to the fused transform pass.Sourcefn transform_html(
&self,
html: &str,
_path: &Path,
_ctx: &PluginContext,
) -> Result<String, SsgError>
fn transform_html( &self, html: &str, _path: &Path, _ctx: &PluginContext, ) -> Result<String, SsgError>
Per-file HTML transform hook — called once per HTML file during
the fused transform pass. Read more
Sourcefn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
fn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
Called after site compilation completes. Read more
Sourcefn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
fn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
Called before site compilation begins. Read more
Sourcefn needs_all_files(&self) -> bool
fn needs_all_files(&self) -> bool
Returns
true if this plugin must always observe the full
cache.html_files() list — even during --incremental
rebuilds that only invalidated a handful of pages. Read moreAuto Trait Implementations
impl Freeze for HighlightPlugin
impl RefUnwindSafe for HighlightPlugin
impl Send for HighlightPlugin
impl Sync for HighlightPlugin
impl Unpin for HighlightPlugin
impl UnsafeUnpin for HighlightPlugin
impl UnwindSafe for HighlightPlugin